Programming Guide
=================

This guide covers programming with **XBR** for decentralized data trading
and service microtransactions.

.. toctree::
   :maxdepth: 2

   ../dev/index
   ../project/index
   ../api/index
   ../xbr
   ../xbr-auth
   ../xbr-cli
